BatchAnnotateFilesResponse class

Response to a batch image annotation request.

Annotations
  • @JsonSerializable.new()

Constructors

BatchAnnotateFilesResponse({required List<AnnotateFileResponse> responses})
BatchAnnotateFilesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
responses List<AnnotateFileResponse>
The list of file annotation responses, each response corresponding to each AnnotateFileRequest in BatchAnnotateFilesRequest.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited