responses property
The list of file annotation responses, each response corresponding to each AnnotateFileRequest in BatchAnnotateFilesRequest.
Implementation
final List<AnnotateFileResponse> responses;
The list of file annotation responses, each response corresponding to each AnnotateFileRequest in BatchAnnotateFilesRequest.
final List<AnnotateFileResponse> responses;