FilesClient class abstract

Service that performs image detection and annotation for a batch of files. Now only "application/pdf", "image/tiff" and "image/gif" are supported.

This service will extract at most 5 (customers can specify which 5 in AnnotateFileRequest.pages) frames (gif) or pages (pdf or tiff) from each file provided and perform detection and annotation for each image extracted.

Annotations
  • @RestApi.new(baseUrl: 'https://vision.googleapis.com/v1')

Constructors

FilesClient(Dio dio, {String baseUrl, ParseErrorLogger? errorLogger})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

annotate(String contentType, Map<String, dynamic> params) Future<BatchAnnotateFilesResponse>
Run image detection and annotation for a batch of images.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited