AnnotateFileResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
AnnotateFileResponse({String? inputConfig, List<
AnnotateImageResponse> ? responses, required int totalPages, Status? error}) -
AnnotateFileResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- error → Status?
-
If set, represents the error message for the failed request. The responses
field will not be set in this case.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputConfig → String?
-
Information about the file for which this response is generated.
final
-
responses
→ List<
AnnotateImageResponse> ? -
Individual responses to images found within the file. This field will be
empty if the error field is set.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalPages → int
-
This field gives the total number of pages in the file.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited