InputConfig class
Constructors
- InputConfig({GcsSource? gcsSource, ByteBuffer? content, required String mimeType})
- InputConfig.fromBuffer(ByteBuffer buffer, [String? mimeType])
-
factory
- InputConfig.fromGsUri(String gsUri)
-
factory
-
InputConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- content → ByteBuffer?
-
File content, represented as a stream of bytes. Note: As with all bytes
fields, protobuffers use a pure binary representation, whereas JSON
representations use base64.
final
- gcsSource → GcsSource?
-
The Google Cloud Storage location to read the input from.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType → String
-
The type of the file. Currently only "application/pdf", "image/tiff" and
"image/gif" are supported. Wildcards are not supported.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
mimeTypeFromContent(
ByteBuffer content) → String -
mimeTypeFromFileName(
String fileName) → String
Constants
- maxContentBytes → const int
- Maximum file size supported by the Google Vision API (20 MB).